The Places365-Standard dataset contains 1.8 million train images from 365 scene
categories, which are used to train the Places365 CNNs. There are 50 images per
category in the validation set and 900 images per category in the testing set.
